# coding: utf-8

"""
    aind-metadata-service

     ## aind-metadata-service  Service to pull data from example backend.  

    The version of the OpenAPI document: 2.3.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from aind_metadata_service_async_client.models.aind_metadata_service_server_routes_slims_slims_workflow import AindMetadataServiceServerRoutesSlimsSlimsWorkflow

class TestAindMetadataServiceServerRoutesSlimsSlimsWorkflow(unittest.TestCase):
    """AindMetadataServiceServerRoutesSlimsSlimsWorkflow unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAindMetadataServiceServerRoutesSlimsSlimsWorkflow(self):
        """Test AindMetadataServiceServerRoutesSlimsSlimsWorkflow"""
        # inst = AindMetadataServiceServerRoutesSlimsSlimsWorkflow()

if __name__ == '__main__':
    unittest.main()
